summaryrefslogtreecommitdiffstats
path: root/chrome/common/temp_scaffolding_stubs.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/temp_scaffolding_stubs.h')
-rw-r--r--chrome/common/temp_scaffolding_stubs.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/chrome/common/temp_scaffolding_stubs.h b/chrome/common/temp_scaffolding_stubs.h
index 394e81d..aebbc8d 100644
--- a/chrome/common/temp_scaffolding_stubs.h
+++ b/chrome/common/temp_scaffolding_stubs.h
@@ -109,13 +109,14 @@ class X509Certificate;
//---------------------------------------------------------------------------
// These stubs are for Browser_main()
-// TODO(port): MessageWindow is very windows-specific, but provides the concept
-// of singleton browser process per user-data-dir. Investigate how
-// to achieve this on other platforms and see if this API works.
-class MessageWindow {
- public:
- explicit MessageWindow(const FilePath& user_data_dir) { }
- ~MessageWindow() { }
+// TODO(port): the current ProcessSingleton implementation is very
+// windows-specific, but provides the concept of a singleton browser
+// process per user-data-dir. Investigate how achieve this on other
+// platforms and see if this API works.
+class ProcessSingleton {
+ public:
+ explicit ProcessSingleton(const FilePath& user_data_dir) { }
+ ~ProcessSingleton() { }
bool NotifyOtherProcess() {
NOTIMPLEMENTED();
return false;